from setuptools import setup, find_packages

name = 'mandarindb'
version = '1.4.1'
readme = f'''# Mandarin databases {version}

# Installation:
## Main way:
```bash
pip install mandarindb
```
## Second way:
```bash
pip install mandarindb=={version}
```

# Changelog:

## Fixed:
- **CLI**: CLI was fixed! You can run it by using `python -m mandarindb`

'''

setup(
    name=name,
    version=version,
    description='Mandarin Databases',
    long_description=readme,
    long_description_content_type='text/markdown',
    install_requires=[],
    author='kanderusss',
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    python_requires='>=3.6',
    author_email='kanderusss.dev@gmail.com',
    url=f"https://pypi.org/project/{name}/",
    project_urls={
        "Documentation": f"https://pypi.org/project/{name}/",
    },
    packages=find_packages(),
    license='MIT'
)
